==> jc-1.4.0.tar.gz: jasmin/Main.h <==
// public class jasmin.Main

// class file dependencies
// @dep_class 92a77559e5386d6a jasmin_Main
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_Main_H_
#define _JC_jasmin_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jasmin_Main$sub_refs	_jc_jasmin_Main$sub_refs;
typedef struct _jc_jasmin_Main$sub_nonrefs	_jc_jasmin_Main$sub_nonrefs;
typedef struct _jc_jasmin_Main$refs	_jc_jasmin_Main$refs;
typedef struct _jc_jasmin_Main$nonrefs	_jc_jasmin_Main$nonrefs;
typedef struct _jc_jasmin_Main$object	_jc_jasmin_Main$object;

typedef struct _jc_jasmin_Main$fields_struct	_jc_jasmin_Main$fields_struct;
typedef const struct _jc_jasmin_Main$vmethods	_jc_jasmin_Main$vmethods;
typedef const struct _jc_jasmin_Main$vtable	_jc_jasmin_Main$vtable;
typedef const struct _jc_jasmin_Main$vtype	_jc_jasmin_Main$vtype;

// Class fields structure
struct _jc_jasmin_Main$fields_struct {
	struct _jc_java_lang_String$object	*version;
};
extern _jc_jasmin_Main$fields_struct _jc_jasmin_Main$class_fields;

// Constructors
extern void _jc_jasmin_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_Main$object *);

// Static methods
extern void _jc_jasmin_Main$method$assemble$6356041394e804ee(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_jasmin_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_jasmin_Main$vmethods {
};

// Vtable
struct _jc_jasmin_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_Main$vmethods	jasmin_Main;
};

// Vtype
struct _jc_jasmin_Main$vtype {
	_jc_type			type;
	_jc_jasmin_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_Main$refs {
    _jc_jasmin_Main$sub_refs	jasmin_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_Main$sub_nonrefs	jasmin_Main;
};

// Object instance structure
struct _jc_jasmin_Main$object {
	_jc_jasmin_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_Main$vtype	*vtype;
	_jc_jasmin_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_Main$vtype _jc_jasmin_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_Main$class_object;

#endif	/* _JC_jasmin_Main_H_ */

==> jc-1.4.6.tar.gz: jasmin/Main.h <==
// public class jasmin.Main

// class file dependencies
// @dep_class 92a77559e5386d6a jasmin_Main
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_Main_H_
#define _JC_jasmin_Main_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jasmin_Main$sub_refs	_jc_jasmin_Main$sub_refs;
typedef struct _jc_jasmin_Main$sub_nonrefs	_jc_jasmin_Main$sub_nonrefs;
typedef struct _jc_jasmin_Main$refs	_jc_jasmin_Main$refs;
typedef struct _jc_jasmin_Main$nonrefs	_jc_jasmin_Main$nonrefs;
typedef struct _jc_jasmin_Main$object	_jc_jasmin_Main$object;

typedef struct _jc_jasmin_Main$fields_struct	_jc_jasmin_Main$fields_struct;
typedef const struct _jc_jasmin_Main$vmethods	_jc_jasmin_Main$vmethods;
typedef const struct _jc_jasmin_Main$vtable	_jc_jasmin_Main$vtable;
typedef const struct _jc_jasmin_Main$vtype	_jc_jasmin_Main$vtype;

// Class fields structure
struct _jc_jasmin_Main$fields_struct {
	struct _jc_java_lang_String$object	*version;
};
extern _jc_jasmin_Main$fields_struct _jc_jasmin_Main$class_fields;

// Constructors
extern void _jc_jasmin_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_Main$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_jasmin_Main$method$assemble$6356041394e804ee(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_jasmin_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_Main$vmethods {
};

// Vtable
struct _jc_jasmin_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_Main$vmethods	jasmin_Main;
};

// Vtype
struct _jc_jasmin_Main$vtype {
	_jc_type			type;
	_jc_jasmin_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_Main$refs {
    _jc_jasmin_Main$sub_refs	jasmin_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_Main$sub_nonrefs	jasmin_Main;
};

// Object instance structure
struct _jc_jasmin_Main$object {
	_jc_jasmin_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_Main$vtype	*vtype;
	_jc_jasmin_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_Main$vtype _jc_jasmin_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_Main$class_object;

#endif	/* _JC_jasmin_Main_H_ */
